# Sarmat.

Библиотека для построения решений в сфере пассажирского транспорта.

Основу работы библиотеки составляют объекты для построения рейсов
и шаблонов для них, выполнения диспетчерских операций,
и управления автотранспортом.

## Состав библиотеки

Библиотека состоит из набора тематических модулей, у каждого из которых своя область
применения:

* Сущности для описания справочников
* Сущности для построения рейсов и маршрутов
* Сущности для описания работы транспортной компании.
* Сущности и инструмент для построения станционного расписания
